@@ -20,18 +20,26 @@ def fun_control_init(
 ):
     """Initialize fun_control dictionary.
     Args:
-        task (str): The task to perform. It can be either "classification" or "regression".
-        _L_in (int): The number of input features.
-        _L_out (int): The number of output features.
-        enable_progress_bar (bool): Whether to enable the progress bar or not.
-        spot_tensorboard_path (str): The path to the folder where the spot tensorboard files are saved.
-        If None, no spot tensorboard files are saved.
-        num_workers (int): The number of workers to use for the data loading.
-        device (str): The device to use for the training. It can be either "cpu", "mps", or "cuda".
+        task (str):
+            The task to perform. It can be either "classification" or "regression".
+        _L_in (int):
+            The number of input features.
+        _L_out (int):
+            The number of output features.
+        enable_progress_bar (bool):
+            Whether to enable the progress bar or not.
+        spot_tensorboard_path (str):
+            The path to the folder where the spot tensorboard files are saved.
+            If None, no spot tensorboard files are saved.
+        num_workers (int):
+            The number of workers to use for the data loading.
+        device (str):
+            The device to use for the training. It can be either "cpu", "mps", or "cuda".
     Returns:
-        fun_control (dict): A dictionary containing the information about the core model, loss function, metrics,
-        and the hyperparameters.
-    Example:
+        fun_control (dict):
+            A dictionary containing the information about the core model,
+            loss function, metrics, and the hyperparameters.
+    Examples:
         >>> fun_control = fun_control_init(_L_in=64, _L_out=11, num_workers=0, device=None)
         >>> fun_control
         >>> {'CHECKPOINT_PATH': 'saved_models/',
@@ -74,7 +82,7 @@ def fun_control_init(
     L.seed_everything(42)
 
     # Path to the folder where the pretrained models are saved
-    CHECKPOINT_PATH = os.environ.get("PATH_CHECKPOINT", "saved_models/")
+    CHECKPOINT_PATH = os.environ.get("PATH_CHECKPOINT", "runs/saved_models/")
     os.makedirs(CHECKPOINT_PATH, exist_ok=True)
     # Path to the folder where the datasets are/should be downloaded (e.g. MNIST)
     DATASET_PATH = os.environ.get("PATH_DATASETS", "data/")
@@ -111,6 +119,8 @@ def fun_control_init(
         "_L_out": _L_out,
         "data": None,
         "data_dir": "./data",
+        "data_module": None,
+        "data_set": None,
         "device": device,
         "enable_progress_bar": enable_progress_bar,
         "eval": None,
@@ -147,7 +157,10 @@ def check_and_create_dir(path):
     Args:
         path (str): Path to the directory.
     Returns:
-        None
+        (noneType): None
+    Examples:
+        >>> fromspotPy.utils.init import check_and_create_dir
+        >>> check_and_create_dir("data/")
     """
     if not isinstance(path, str):
         raise Exception("path must be a string")
